ProgressDialog — pyqtgraph 0.11.0rc0 documentation

# ProgressDialog

class `pyqtgraph.` `ProgressDialog`(labelText, minimum=0, maximum=100, cancelText='Cancel', parent=None, wait=250, busyCursor=False, disable=False, nested=False)

  Extends QProgressDialog:

  - Adds context management so the dialog may be used in with statements

  - Allows nesting multiple progress dialogs

  Example:

      with ProgressDialog("Processing..", minVal, maxVal) as dlg:
          # do stuff
          dlg.setValue(i)   ## could also use dlg += 1
          if dlg.wasCanceled():
              raise Exception("Processing canceled by user")

  `__init__`(labelText, minimum=0, maximum=100, cancelText='Cancel', parent=None, wait=250, busyCursor=False, disable=False, nested=False)

    Arguments: |
    labelText | (required)
    cancelText | Text to display on cancel button, or None to disable it.
    minimum |
    maximum |
    parent |
    wait | Length of time (im ms) to wait before displaying dialog
    busyCursor | If True, show busy cursor until dialog finishes
    disable | If True, the progress dialog will not be displayed and calls to wasCanceled() will always return False. If ProgressDialog is entered from a non-gui thread, it will always be disabled.
    nested | (bool) If True, then this progress bar will be displayed inside any pre-existing progress dialogs that also allow nesting.

  `maximum`(self) → int
  `minimum`(self) → int
  `resizeEvent`(self, event: PySide2.QtGui.QResizeEvent)
  `setLabelText`(self, text: str)
  `setMaximum`(self, maximum: int)
  `setMinimum`(self, minimum: int)
  `setValue`(self, progress: int)
  `wasCanceled`(self) → bool